@@ -211,7 +211,7 @@ static bool create_name_map(Cursor* cur, SQLSMALLINT field_count, bool lower)
 
         TRACE("Col %d: type=%s (%d) colsize=%d\n", (i+1), SqlTypeName(nDataType), (int)nDataType, (int)nColSize);
 
-        Object name(TextBufferToObject(enc, szName, cbName));
+        Object name(TextBufferToObject(enc, (byte*)szName, cbName));
 
         if (!name)
             goto done;
