@@ -20,6 +20,7 @@
 #include "cnxninfo.h"
 #include "params.h"
 #include "dbspecific.h"
+#include "decimal.h"
 #include <datetime.h>
 
 #include <time.h>
@@ -152,9 +153,6 @@ bool UseNativeUUID()
 
 HENV henv = SQL_NULL_HANDLE;
 
-Py_UNICODE chDecimal = '.';
-
-
 PyObject* GetClassForThread(const char* szModule, const char* szClass)
 {
     // Returns the given class, specific to the current thread's interpreter.  For performance
@@ -249,36 +247,6 @@ bool IsInstanceForThread(PyObject* param, const char* szModule, const char* szCl
 }
 
 
-// Initialize the global decimal character and thousands separator character, used when parsing decimal
-// objects.
-//
-static void init_locale_info()
-{
-    Object module(PyImport_ImportModule("locale"));
-    if (!module)
-    {
-        PyErr_Clear();
-        return;
-    }
-
-    Object ldict(PyObject_CallMethod(module, "localeconv", 0));
-    if (!ldict)
-    {
-        PyErr_Clear();
-        return;
-    }
-
-    PyObject* value = PyDict_GetItemString(ldict, "decimal_point");
-    if (value)
-    {
-        if (PyBytes_Check(value) && PyBytes_Size(value) == 1)
-            chDecimal = (Py_UNICODE)PyBytes_AS_STRING(value)[0];
-        if (PyUnicode_Check(value) && PyUnicode_GET_SIZE(value) == 1)
-            chDecimal = PyUnicode_AS_UNICODE(value)[0];
-    }
-}
-
-
 static bool import_types()
 {
     // Note: We can only import types from C extensions since they are shared among all
@@ -300,6 +268,8 @@ static bool import_types()
     GetData_init();
     if (!Params_init())
         return false;
+    if (!InitializeDecimal())
+        return false;
 
     return true;
 }
@@ -708,24 +678,25 @@ static PyObject* mod_timestampfromticks(PyObject* self, PyObject* args)
 static PyObject* mod_setdecimalsep(PyObject* self, PyObject* args)
 {
     UNUSED(self);
-    if (!PyString_Check(PyTuple_GET_ITEM(args, 0)) && !PyUnicode_Check(PyTuple_GET_ITEM(args, 0)))
-        return PyErr_Format(PyExc_TypeError, "argument 1 must be a string or unicode object");
 
-    PyObject* value = PyUnicode_FromObject(PyTuple_GetItem(args, 0));
-    if (value)
-    {
-        if (PyBytes_Check(value) && PyBytes_Size(value) == 1)
-            chDecimal = (Py_UNICODE)PyBytes_AS_STRING(value)[0];
-        if (PyUnicode_Check(value) && PyUnicode_GET_SIZE(value) == 1)
-            chDecimal = PyUnicode_AS_UNICODE(value)[0];
-    }
+#if PY_MAJOR_VERSION >= 3
+    const char* type = "U";
+#else
+    const char* type = "S";
+#endif
+
+    PyObject* p;
+    if (!PyArg_ParseTuple(args, type, &p))
+        return 0;
+    if (!SetDecimalPoint(p))
+        return 0;
     Py_RETURN_NONE;
 }
 
 static PyObject* mod_getdecimalsep(PyObject* self)
 {
     UNUSED(self);
-    return PyUnicode_FromUnicode(&chDecimal, 1);
+    return GetDecimalPoint();
 }
 
 static char connect_doc[] =
@@ -1245,8 +1216,6 @@ initpyodbc(void)
     if (!module || !import_types() || !CreateExceptions())
         return MODRETURN(0);
 
-    init_locale_info();
-
     const char* szVersion = TOSTRING(PYODBC_VERSION);
     PyModule_AddStringConstant(module, "version", (char*)szVersion);
 
