@@ -2,7 +2,7 @@
 # -*- coding: latin-1 -*-
 
 usage = """\
-usage: %prog [options] connection_string
+%(prog)s [options] connection_string
 
 Unit tests for Informix DB.  To use, pass a connection string as the parameter.
 The tests will create and drop tables t1 and t2 as necessary.
@@ -1221,34 +1221,35 @@ class InformixTestCase(unittest.TestCase):
 
 
 def main():
-    from optparse import OptionParser
-    parser = OptionParser(usage=usage)
-    parser.add_option("-v", "--verbose", action="count", help="Increment test verbosity (can be used multiple times)")
-    parser.add_option("-d", "--debug", action="store_true", default=False, help="Print debugging items")
-    parser.add_option("-t", "--test", help="Run only the named test")
+    from argparse import ArgumentParser
+    parser = ArgumentParser(usage=usage)
+    parser.add_argument("-v", "--verbose", action="count", help="increment test verbosity (can be used multiple times)")
+    parser.add_argument("-d", "--debug", action="store_true", default=False, help="print debugging items")
+    parser.add_argument("-t", "--test", help="run only the named test")
+    parser.add_argument("conn_str", nargs="*", help="connection string for Informix")
 
-    (options, args) = parser.parse_args()
+    args = parser.parse_args()
 
-    if len(args) > 1:
+    if len(args.conn_str) > 1:
         parser.error('Only one argument is allowed.  Do you need quotes around the connection string?')
 
-    if not args:
+    if not args.conn_str:
         connection_string = load_setup_connection_string('informixtests')
 
         if not connection_string:
             parser.print_help()
             raise SystemExit()
     else:
-        connection_string = args[0]
+        connection_string = args.conn_str[0]
 
-    if options.verbose:
+    if args.verbose:
         cnxn = pyodbc.connect(connection_string)
         print_library_info(cnxn)
         cnxn.close()
 
-    suite = load_tests(InformixTestCase, options.test, connection_string)
+    suite = load_tests(InformixTestCase, args.test, connection_string)
 
-    testRunner = unittest.TextTestRunner(verbosity=options.verbose)
+    testRunner = unittest.TextTestRunner(verbosity=args.verbose)
     result = testRunner.run(suite)
 
     return result
