@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 usage = """\
-usage: %prog [options] connection_string
+%(prog)s [options] connection_string
 
 Unit tests for Apache Spark. To use, pass a connection string as the parameter.
 The tests will create and drop tables t1 and t2 as necessary.
@@ -489,46 +489,47 @@ class SparkTestCase(unittest.TestCase):
         self.assertEqual(result, v)
        
 def main():
-    from optparse import OptionParser
-    parser = OptionParser(usage="usage: %prog [options] connection_string")
-    parser.add_option("-v", "--verbose", default=0, action="count", help="Increment test verbosity (can be used multiple times)")
-    parser.add_option("-d", "--debug", action="store_true", default=False, help="Print debugging items")
-    parser.add_option("-t", "--test", help="Run only the named test")
-    parser.add_option('-a', '--ansi', help='ANSI only', default=False, action='store_true')
+    from argparse import ArgumentParser
+    parser = ArgumentParser(usage=usage)
+    parser.add_argument("-v", "--verbose", action="count", default=0, help="increment test verbosity (can be used multiple times)")
+    parser.add_argument("-d", "--debug", action="store_true", default=False, help="print debugging items")
+    parser.add_argument("-t", "--test", help="run only the named test")
+    parser.add_argument("-a", "--ansi", help="ANSI only", default=False, action="store_true")
+    parser.add_argument("conn_str", nargs="*", help="connection string for Spark")
 
-    (options, args) = parser.parse_args()
+    args = parser.parse_args()
 
-    if len(args) > 1:
+    if len(args.conn_str) > 1:
         parser.error('Only one argument is allowed.  Do you need quotes around the connection string?')
 
-    if not args:
+    if not args.conn_str:
         connection_string = load_setup_connection_string('sparktests')
 
         if not connection_string:
             parser.print_help()
             raise SystemExit()
     else:
-        connection_string = args[0]
+        connection_string = args.conn_str[0]
 
-    if options.verbose:
-        cnxn = pyodbc.connect(connection_string, ansi=options.ansi)
+    if args.verbose:
+        cnxn = pyodbc.connect(connection_string, ansi=args.ansi)
         print_library_info(cnxn)
         cnxn.close()
 
-    if options.test:
+    if args.test:
         # Run a single test
-        if not options.test.startswith('test_'):
-            options.test = 'test_%s' % (options.test)
+        if not args.test.startswith('test_'):
+            args.test = 'test_%s' % (args.test)
 
-        s = unittest.TestSuite([ SparkTestCase(connection_string, options.ansi, options.test) ])
+        s = unittest.TestSuite([ SparkTestCase(connection_string, args.ansi, args.test) ])
     else:
         # Run all tests in the class
 
         methods = [ m for m in dir(SparkTestCase) if m.startswith('test_') ]
         methods.sort()
-        s = unittest.TestSuite([ SparkTestCase(connection_string, options.ansi, m) for m in methods ])
+        s = unittest.TestSuite([ SparkTestCase(connection_string, args.ansi, m) for m in methods ])
 
-    testRunner = unittest.TextTestRunner(verbosity=options.verbose)
+    testRunner = unittest.TextTestRunner(verbosity=args.verbose)
     result = testRunner.run(s)
 
     return result
